# Changelog

## 1.1.0 - 2022-10-20

### Added

* Allow selection and removal of multiple entries
* Add Delete key shortcut for removal of entries
* Allow rearranging of expressions using Drag & Drop
* Add “Copy value” action to context menu

### Changed

* Insert new expressions at drop position when text is dropped onto the Watchlist
* Insert new expression at the last position the user clicked when “Add expression” is used (instead of always appending at the end of the list)
* Select the next expression following the removed expression when “Remove expression” is used. Select the previous (= new last) expression if the last expression is removed.
* Don’t sort expressions when they are saved (when the plugin is closed): Retain the order now that it’s possible to rearrange expressions using Drag & Drop.

## 1.0.0 - 2022-07-06

* First public release
